pub struct PartitionTableBlock { /* private fields */ }Expand description
Describes a partition table.
Don’t store this as a static - make sure you convert it to a block.
Implementations
Sourceimpl PartitionTableBlock
impl PartitionTableBlock
Sourcepub const fn new() -> PartitionTableBlock
pub const fn new() -> PartitionTableBlock
Create an empty Block, big enough for a partition table.
At a minimum you need to call Self::add_partition_item.
Sourcepub const fn add_partition_item(
self,
unpartitioned: UnpartitionedSpace,
partitions: &[Partition],
) -> Self
pub const fn add_partition_item( self, unpartitioned: UnpartitionedSpace, partitions: &[Partition], ) -> Self
Add a partition to the partition table
Sourcepub const fn with_version(self, major: u16, minor: u16) -> Self
pub const fn with_version(self, major: u16, minor: u16) -> Self
Add a version number to the partition table
Sourcepub const fn with_sha256(self) -> Self
pub const fn with_sha256(self) -> Self
Add a a SHA256 hash of the Block
Adds a HASH_DEF covering all the previous items in the Block, and a
HASH_VALUE with a SHA-256 hash of them.