Stack

Struct Stack 

pub struct Stack<const SIZE: usize> { /* private fields */ }
Data type for a properly aligned stack of N 32-bit (usize) words

Implementations

Source

impl<const SIZE: usize> Stack<SIZE>

pub const fn new() -> Stack<SIZE>

Construct a stack of length SIZE, initialized to 0

The minimum allowed SIZE is 64 bytes, but most programs will need a significantly larger stack.

pub fn take(&self) -> Option<StackAllocation>

Take the StackAllocation out of this Stack.

This returns None if the stack is already taken.

pub unsafe fn reset(&self)

Reset the taken flag of the stack area

Safety

The caller must ensure that the stack is no longer in use, eg. because the core that used it was reset. This method doesn’t do any synchronization so it must not be called from multiple threads concurrently.