StackAllocation

Struct StackAllocation 

pub struct StackAllocation { /* private fields */ }
This object represents a memory area which can be used for a stack.

It is essentially a range of pointers with these additional guarantees: The begin / end pointers must define a stack with proper alignment (at least 8 bytes, preferably 32 bytes) and sufficient size (64 bytes would be sound but much too little for most real-world workloads). The underlying memory must have a static lifetime and must be owned by the object exclusively. No mutable references to that memory must exist. Therefore, a function that gets passed such an object is free to write to arbitrary memory locations in the range.

Implementations

Source

impl StackAllocation

pub unsafe fn from_raw_parts(start: *mut usize, end: *mut usize) -> Self

Unsafely construct a stack allocation

This is mainly useful to construct a stack allocation in some memory region defined in a linker script, for example to place the stack in the SRAM8/9 regions.

Safety

The caller must ensure that the guarantees that a StackAllocation provides are upheld.