pub struct Stack<const SIZE: usize> { /* private fields */ }Expand description
Data type for a properly aligned stack of N 32-bit (usize) words
Implementations
Sourceimpl<const SIZE: usize> Stack<SIZE>
impl<const SIZE: usize> Stack<SIZE>
Sourcepub const fn new() -> Stack<SIZE>
pub const fn new() -> Stack<SIZE>
Construct a stack of length SIZE, initialized to 0
The minimum allowed SIZE is 64 bytes, but most programs will need a significantly larger stack.
Sourcepub fn take(&self) -> Option<StackAllocation>
pub fn take(&self) -> Option<StackAllocation>
Take the StackAllocation out of this Stack.
This returns None if the stack is already taken.